src/hg/utils/automation/makePushQSql.pl 1.23
1.23 2009/03/20 23:01:23 angie
Use hgofbeta instead of hgwbeta as the mysql server for qapushq.
Index: src/hg/utils/automation/makePushQSql.pl
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/utils/automation/makePushQSql.pl,v
retrieving revision 1.22
retrieving revision 1.23
diff -b -B -U 4 -r1.22 -r1.23
--- src/hg/utils/automation/makePushQSql.pl 3 Mar 2009 21:46:23 -0000 1.22
+++ src/hg/utils/automation/makePushQSql.pl 20 Mar 2009 23:01:23 -0000 1.23
@@ -581,9 +581,9 @@
# to the new $db push queue created above.
my $date = `date +%Y-%m-%d`;
my $size = 0;
chomp $date;
- my $qapushqSql = 'ssh -x hgwbeta hgsql -N qapushq';
+ my $qapushqSql = 'ssh -x hgwbeta hgsql -h hgofbeta -N qapushq';
my $rankQuery = 'select rank from pushQ order by rank desc limit 1';
my $rank = `echo $rankQuery | $qapushqSql`;
$rank += 1;
my (undef, undef, $assemblyLabel) =
@@ -648,14 +648,14 @@
*** 5. This script currently does not recognize composite tracks. If $db
has any composite tracks, you should manually merge the separate
per-table entries into one entry.
*** 6. Make sure that qapushq does not already have a table named $db:
- ssh hgwbeta hgsql qapushq -NBe "'desc $db;'"
+ ssh hgwbeta hgsql -h hgofbeta qapushq -NBe "'desc $db;'"
You *should* see this error:
ERROR 1146 at line 1: Table 'qapushq.$db' doesn't exist
If it already has that table, talk to QA and figure out whether
it can be dropped or fixed up (by sql or the Push Queue web app).
*** When everything is complete and correct, use hgsql on hgwbeta to
execute the sql file. Then use the Push Queue web app to check the
contents of all entries.
*** If you haven't already, please add $db to makeDb/schema/all.joiner !
@@ -648,14 +648,14 @@
If it already has that table, talk to QA and figure out whether
it can be dropped or fixed up (by sql or the Push Queue web app).
- *** When everything is complete and correct, use hgsql on hgwbeta to
+ *** When everything is complete and correct, use hgsql -h hgofbeta to
execute the sql file. Then use the Push Queue web app to check the
contents of all entries.
It should be in both \$gbd and \$chainDest.